@@ -1,19 +1,15 @@
 import typing as t
 
+from ellar.common.constants import SCOPE_RESPONSE_STARTED, SCOPE_SERVICE_PROVIDER
+from ellar.common.interfaces import IExceptionHandler, IHostContext, IHostContextFactory
+from ellar.common.responses import Response
+from ellar.common.types import ASGIApp, TMessage, TReceive, TScope, TSend
+from ellar.core.connection.http import Request
+from ellar.di import EllarInjector
 from starlette.middleware.errors import ServerErrorMiddleware
 from starlette.requests import Request as StarletteRequest
 from starlette.responses import JSONResponse
 
-from ellar.constants import SCOPE_RESPONSE_STARTED, SCOPE_SERVICE_PROVIDER
-from ellar.core.connection.http import Request
-from ellar.core.context import IHostContext
-from ellar.core.response import Response
-from ellar.di import EllarInjector
-from ellar.types import ASGIApp, TMessage, TReceive, TScope, TSend
-
-if t.TYPE_CHECKING:  # pragma: no cover
-    from ellar.core.exceptions.interfaces import IExceptionHandler
-
 
 class RequestServiceProviderMiddleware(ServerErrorMiddleware):
     def __init__(
@@ -22,7 +18,7 @@ class RequestServiceProviderMiddleware(ServerErrorMiddleware):
         *,
         debug: bool,
         injector: "EllarInjector",
-        handler: "IExceptionHandler" = None
+        handler: t.Optional["IExceptionHandler"] = None,
     ) -> None:
         _handler = None
         if handler:
@@ -30,7 +26,9 @@ class RequestServiceProviderMiddleware(ServerErrorMiddleware):
             _handler = self.error_handler
 
         super(RequestServiceProviderMiddleware, self).__init__(
-            debug=debug, handler=_handler, app=app
+            debug=debug,
+            handler=_handler,  # type:ignore[arg-type]
+            app=app,
         )
 
         self.injector = injector
@@ -43,30 +41,38 @@ class RequestServiceProviderMiddleware(ServerErrorMiddleware):
         scope[SCOPE_RESPONSE_STARTED] = False
 
         async def sender(message: TMessage) -> None:
-            if message["type"] == "http.response.start":
+            if (
+                message["type"] == "http.response.start"
+                or message["type"] == "websocket.accept"
+            ):
                 scope[SCOPE_RESPONSE_STARTED] = True
             await send(message)
             return
 
-        async with self.injector.create_asgi_args(
-            scope, receive, sender
-        ) as service_provider:
+        async with self.injector.create_asgi_args() as service_provider:
             scope[SCOPE_SERVICE_PROVIDER] = service_provider
 
-            host_context: IHostContext = service_provider.get(IHostContext)
+            context_factory = service_provider.get(IHostContextFactory)
+            service_provider.update_scoped_context(
+                IHostContext, context_factory.create_context(scope)
+            )
 
-            if host_context.get_type() == "http":
-                await super().__call__(*host_context.get_args())
+            if scope["type"] == "http":
+                await super().__call__(scope, receive, sender)
             else:
-                await self.app(*host_context.get_args())
+                await self.app(scope, receive, sender)
 
     async def error_handler(self, request: Request, exc: Exception) -> Response:
-        host_context = request.scope[SCOPE_SERVICE_PROVIDER].get(IHostContext)
+        host_context_factory: IHostContextFactory = request.scope[
+            SCOPE_SERVICE_PROVIDER
+        ].get(IHostContextFactory)
+        host_context = host_context_factory.create_context(request.scope)
+
         assert self._500_error_handler
         response = await self._500_error_handler.catch(host_context, exc)
         return response
 
     def error_response(self, request: StarletteRequest, exc: Exception) -> Response:
         return JSONResponse(
-            dict(detail="Internal server error", status_code=500), status_code=500
+            {"detail": "Internal server error", "status_code": 500}, status_code=500
         )
