@@ -1,14 +1,14 @@
 import typing as t
 
-from injector import Binder, Module as _InjectorModule
-
-from ellar.constants import MODULE_FIELDS
-from ellar.core.conf import Config
-from ellar.core.modules.builder import ModuleBaseBuilder
+from ellar.common.constants import MODULE_FIELDS
 from ellar.di.injector import Container
+from injector import Binder
+from injector import Module as _InjectorModule
+
+from .builder import ModuleBaseBuilder
 
 if t.TYPE_CHECKING:  # pragma: no cover
-    from ellar.core import App
+    from ellar.core.conf import Config
 
 
 class ModuleBaseMeta(type):
@@ -20,17 +20,16 @@ class ModuleBaseMeta(type):
         cls.__MODULE_FIELDS__: t.Dict = {}
 
         for base in reversed(bases):
-            ModuleBaseBuilder(cls).build(getattr(base, MODULE_FIELDS, dict()))
+            ModuleBaseBuilder(cls).build(getattr(base, MODULE_FIELDS, {}))
         ModuleBaseBuilder(cls).build(namespace)
 
 
 class ModuleBase(_InjectorModule, metaclass=ModuleBaseMeta):
     @classmethod
-    def before_init(cls, config: Config) -> None:
-        """Before Module initialisation"""
-
-    def application_ready(self, app: "App") -> None:
-        """Application Ready"""
+    def before_init(cls, config: "Config") -> t.Dict:
+        """Before Module initialisation. Whatever value that is returned here will be passed
+        to the Module constructor during initialisation"""
+        return {}
 
     def register_services(self, container: Container) -> None:
         """Register other services manually"""
