@@ -1,12 +1,10 @@
 from typing import Optional
 from uuid import UUID
 
-from pydantic import Field
-
-from ellar.common import ModuleRouter, Path, Query
+from ellar.app import AppFactory
+from ellar.common import Inject, ModuleRouter, Path, Query, Serializer
 from ellar.core.connection import Request
-from ellar.core.factory import AppFactory
-from ellar.core.schema import Schema
+from pydantic import Field
 
 router = ModuleRouter("")
 
@@ -205,7 +203,7 @@ def get_query_param_required_type(query: int = Query(...)):
     return f"foo bar {query}"
 
 
-class AliasedSchema(Schema):
+class AliasedSchema(Serializer):
     query: str = Field(..., alias="aliased.-_~name")
 
 
@@ -215,7 +213,7 @@ def get_query_aliased_name(query: AliasedSchema = Query(..., alias="aliased.-_~n
 
 
 @router.get("/query/param")
-def get_query_param(request: Request, query=Query(None)):
+def get_query_param(request: Inject[Request], query=Query(None)):
     if query is None:
         return "foo bar"
     return f"foo bar {query}"
