@@ -2,10 +2,9 @@ from dataclasses import dataclass
 from datetime import datetime
 from typing import Optional, Union
 
+from ellar.common import Serializer
 from pydantic import BaseModel, Field
 
-from ellar.core.schema import Schema
-
 
 class BlogObjectDTO:
     title: str
@@ -31,12 +30,12 @@ class User(BaseModel):
     full_name: Optional[str] = None
 
 
-class Filter(Schema):
+class Filter(Serializer):
     to_datetime: datetime = Field(alias="to")
     from_datetime: datetime = Field(alias="from")
 
 
-class CreateCarSchema(Schema):
+class CreateCarSchema(Serializer):
     name: str
     model: str
     brand: str
