@@ -1,8 +1,12 @@
-from starlette.routing import Host, Mount
-
+import pytest
+from ellar.app import AppFactory
 from ellar.common import Module
-from ellar.core import AppFactory, Config, ModuleBase, TestClient
+from ellar.common.constants import MODULE_WATERMARK
+from ellar.core import Config, ModuleBase, ModuleSetup
 from ellar.di import EllarInjector
+from ellar.reflect import reflect
+from ellar.testing import TestClient
+from starlette.routing import Host, Mount
 
 from .sample import (
     AppAPIKey,
@@ -26,17 +30,17 @@ class BModule:
 
 
 def test_factory__read_all_module():
-    modules_dict = AppFactory.read_all_module(module=BModule)
+    modules_dict = AppFactory.read_all_module(ModuleSetup(BModule))
     assert len(modules_dict) == 2
-    assert list(modules_dict.values())[0] is AModule
-    assert list(modules_dict.values())[1] is ApplicationModule
+    assert list(modules_dict.values())[0].module is AModule
+    assert list(modules_dict.values())[1].module is ApplicationModule
 
-    modules_list = AppFactory.get_all_modules(module=AModule)
+    modules_list = AppFactory.get_all_modules(ModuleSetup(AModule))
     assert len(modules_list) == 2
-    assert modules_list[0] is AModule
-    assert modules_list[1] is ApplicationModule
+    assert modules_list[0].module is AModule
+    assert modules_list[1].module is ApplicationModule
 
-    modules_dict = AppFactory.read_all_module(module=ApplicationModule)
+    modules_dict = AppFactory.read_all_module(ModuleSetup(ApplicationModule))
     assert len(modules_dict) == 0
 
 
@@ -50,7 +54,7 @@ def test_factory__build_modules():
     assert len(module_refs) == 3
 
     modules = [AModule, ApplicationModule, BModule]
-    for k, v in module_refs.items():
+    for k, _v in module_refs.items():
         assert k in modules
 
 
@@ -71,8 +75,9 @@ def test_factory_create_app_dynamically_creates_module():
     app = AppFactory.create_app()
     first_module_ref = next(app.get_module_loaders())
     module_instance = first_module_ref.get_module_instance()
-    assert isinstance(module_instance, ModuleBase)
-    assert "ellar.core.factory.Module" in str(module_instance.__class__)
+    assert not isinstance(module_instance, ModuleBase)
+    assert reflect.get_metadata(MODULE_WATERMARK, type(module_instance))
+    assert "ellar.app.factory.Module" in str(module_instance.__class__)
 
 
 def test_factory_create_app_works(tmpdir):
@@ -105,3 +110,10 @@ def test_factory_create_app_works(tmpdir):
     template = app.jinja_environment.get_template("example.html")
     result = template.render()
     assert result == "<html>Hello World<html/>"
+
+
+def test_invalid_config_module_raise_exception():
+    with pytest.raises(Exception) as ex:
+        AppFactory.create_app(config_module=set())
+
+    assert str(ex.value) == "config_module should be a importable str or a dict object"
