@@ -1,44 +1,49 @@
 import os
 import typing as t
 
-import pytest
-from starlette.responses import JSONResponse, PlainTextResponse, Response
-
-from ellar.common import Module, get, template_filter, template_global
-from ellar.compatible import asynccontextmanager
-from ellar.core import (
-    App,
-    AppFactory,
-    Config,
-    ModuleBase,
-    TestClient,
-    TestClientFactory,
+from ellar.app import App, AppFactory
+from ellar.app.services import EllarAppService
+from ellar.common import (
+    IExceptionHandler,
+    IExecutionContext,
+    Inject,
+    Module,
+    get,
+    template_filter,
+    template_global,
 )
+from ellar.common.helper.importer import get_class_import
+from ellar.common.templating import Environment
+from ellar.core import Config, ModuleBase
 from ellar.core.connection import Request
-from ellar.core.context import IExecutionContext, IHostContext
-from ellar.core.events import EventHandler
-from ellar.core.exceptions.interfaces import IExceptionHandler
 from ellar.core.modules import ModuleTemplateRef
-from ellar.core.services import CoreServiceRegistration
+from ellar.core.services.reflector import Reflector
 from ellar.core.staticfiles import StaticFiles
-from ellar.core.templating import Environment
-from ellar.core.versioning import VERSIONING, DefaultAPIVersioning, UrlPathAPIVersioning
+from ellar.core.versioning import (
+    DefaultAPIVersioning,
+    UrlPathAPIVersioning,
+)
+from ellar.core.versioning import (
+    VersioningSchemes as VERSIONING,
+)
 from ellar.di import EllarInjector
-from ellar.helper.importer import get_class_import
 from ellar.openapi import OpenAPIDocumentModule
-from ellar.services.reflector import Reflector
+from ellar.reflect import asynccontextmanager
+from ellar.testing import Test, TestClient
+from starlette.responses import JSONResponse, PlainTextResponse, Response
 
 from .config import ConfigTrustHostConfigure
 from .sample import AppAPIKey, ApplicationModule
 
-test_module = TestClientFactory.create_test_module_from_module(
-    module=ApplicationModule, config_module=get_class_import(ConfigTrustHostConfigure)
+test_module = Test.create_test_module(
+    modules=(ApplicationModule,),
+    config_module=get_class_import(ConfigTrustHostConfigure),
 )
 
 
 class TestStarletteCompatibility:
     def test_func_route(self):
-        client = test_module.get_client()
+        client = test_module.get_test_client()
         response = client.get("/func")
         assert response.status_code == 200
         assert response.text == "Hello, world!"
@@ -48,50 +53,50 @@ class TestStarletteCompatibility:
         assert response.text == ""
 
     def test_async_route(self):
-        client = test_module.get_client()
+        client = test_module.get_test_client()
         response = client.get("/async")
         assert response.status_code == 200
         assert response.text == "Hello, world!"
 
     def test_class_route(self):
-        client = test_module.get_client()
+        client = test_module.get_test_client()
         response = client.get("/classbase/class")
         assert response.status_code == 200
         assert response.text == "Hello, world!"
 
     def test_mounted_route(self):
-        client = test_module.get_client()
+        client = test_module.get_test_client()
         response = client.get("/users/")
         assert response.status_code == 200
         assert response.text == "Hello, everyone!"
 
     def test_mounted_route_path_params(self):
-        client = test_module.get_client()
+        client = test_module.get_test_client()
         response = client.get("/users/tomchristie")
         assert response.status_code == 200
         assert response.text == "Hello, tomchristie!"
 
     def test_subdomain_route(self):
-        client = test_module.get_client(base_url="https://foo.example.org/")
+        client = test_module.get_test_client(base_url="https://foo.example.org/")
 
         response = client.get("/")
         assert response.status_code == 200
         assert response.text == "Subdomain: foo"
 
     def test_websocket_route(self):
-        client = test_module.get_client()
+        client = test_module.get_test_client()
         with client.websocket_connect("/ws") as session:
             text = session.receive_text()
             assert text == "Hello, world!"
 
     def test_400(self):
-        client = test_module.get_client()
+        client = test_module.get_test_client()
         response = client.get("/404")
         assert response.status_code == 404
         assert response.json() == {"detail": "Not Found"}
 
     def test_405(self):
-        client = test_module.get_client()
+        client = test_module.get_test_client()
         response = client.post("/func")
         assert response.status_code == 405
         assert response.json() == {"detail": "Custom message"}
@@ -101,44 +106,17 @@ class TestStarletteCompatibility:
         assert response.json() == {"detail": "Custom message"}
 
     def test_500(self):
-        client = test_module.get_client(raise_server_exceptions=False)
+        client = test_module.get_test_client(raise_server_exceptions=False)
         response = client.get("/classbase/500")
         assert response.status_code == 500
         assert response.json() == {"detail": "Server Error"}
 
     def test_middleware(self):
-        client = test_module.get_client(base_url="http://incorrecthost")
+        client = test_module.get_test_client(base_url="http://incorrecthost")
         response = client.get("/func")
         assert response.status_code == 400
         assert response.text == "Invalid host header"
 
-    def test_app_add_event_handler(self, test_client_factory):
-        startup_complete = False
-        cleanup_complete = False
-
-        def run_startup():
-            nonlocal startup_complete
-            startup_complete = True
-
-        def run_cleanup():
-            nonlocal cleanup_complete
-            cleanup_complete = True
-
-        app = App(
-            config=Config(),
-            injector=EllarInjector(),
-            on_startup_event_handlers=[EventHandler(run_startup)],
-            on_shutdown_event_handlers=[EventHandler(run_cleanup)],
-        )
-
-        assert not startup_complete
-        assert not cleanup_complete
-        with test_client_factory(app):
-            assert startup_complete
-            assert not cleanup_complete
-        assert startup_complete
-        assert cleanup_complete
-
     def test_app_async_cm_lifespan(self, test_client_factory):
         startup_complete = False
         cleanup_complete = False
@@ -150,7 +128,9 @@ class TestStarletteCompatibility:
             yield
             cleanup_complete = True
 
-        app = App(config=Config(), injector=EllarInjector(), lifespan=lifespan)
+        app = Test.create_test_module(
+            config_module={"DEFAULT_LIFESPAN_HANDLER": lifespan}
+        ).create_application()
 
         assert not startup_complete
         assert not cleanup_complete
@@ -162,7 +142,7 @@ class TestStarletteCompatibility:
 
     def test_app_debug_return_html(self):
         @get("/")
-        async def homepage(request: Request):
+        async def homepage(request: Inject[Request]):
             raise RuntimeError()
 
         app = AppFactory.create_app()
@@ -178,7 +158,7 @@ class TestStarletteCompatibility:
 
     def test_app_debug_plain_text(self):
         @get("/")
-        async def homepage(request: Request):
+        async def homepage(request: Inject[Request]):
             raise RuntimeError()
 
         app = AppFactory.create_app()
@@ -195,7 +175,7 @@ class TestStarletteCompatibility:
 class TestEllarApp:
     def test_ellar_as_asgi_app(self):
         @get("/")
-        async def homepage(request: Request, ctx: IExecutionContext):
+        async def homepage(request: Inject[Request], ctx: Inject[IExecutionContext]):
             res = PlainTextResponse("Ellar Route Handler as an ASGI app")
             await res(*ctx.get_args())
 
@@ -206,6 +186,17 @@ class TestEllarApp:
         assert response.status_code == 200
         assert response.text == "Ellar Route Handler as an ASGI app"
 
+    def test_ellar_app_url_for(self):
+        @get("/homepage-url", name="homepage")
+        async def homepage(request: Inject[Request], ctx: Inject[IExecutionContext]):
+            res = PlainTextResponse("Ellar Route Handler as an ASGI app")
+            return res
+
+        app = AppFactory.create_app()
+        app.router.append(homepage)
+        result = app.url_path_for("homepage")
+        assert result == "/homepage-url"
+
     def test_app_staticfiles_route(self, tmpdir):
         path = os.path.join(tmpdir, "example.txt")
         with open(path, "w") as file:
@@ -213,7 +204,7 @@ class TestEllarApp:
 
         config = Config(STATIC_DIRECTORIES=[tmpdir])
         injector = EllarInjector()
-        CoreServiceRegistration(injector).register_all()
+        EllarAppService(injector, config=Config()).register_core_services()
         injector.container.register_instance(config)
         app = App(injector=injector, config=config)
         client = TestClient(app)
@@ -235,7 +226,7 @@ class TestEllarApp:
             STATIC_MOUNT_PATH="/static-modified", STATIC_DIRECTORIES=[tmpdir]
         )
         injector = EllarInjector()
-        CoreServiceRegistration(injector).register_all()
+        EllarAppService(injector, config=Config()).register_core_services()
         injector.container.register_instance(config)
         app = App(injector=injector, config=config)
         client = TestClient(app)
@@ -256,15 +247,16 @@ class TestEllarApp:
         assert module_instance is module_instance2
 
     def test_has_static_files(self, tmpdir):
-        app = App(injector=EllarInjector(), config=Config())
+        app = Test.create_test_module().create_application()
         assert app.has_static_files is False
 
-        config = Config(STATIC_DIRECTORIES=[tmpdir])
-        app = App(injector=EllarInjector(), config=config)
+        app = Test.create_test_module(
+            config_module={"STATIC_DIRECTORIES": [tmpdir]}
+        ).create_application()
         assert app.has_static_files
 
     def test_app_enable_versioning_and_versioning_scheme(self):
-        app = App(injector=EllarInjector(), config=Config())
+        app = Test.create_test_module().create_application()
         assert app.config.VERSIONING_SCHEME
         assert isinstance(app.config.VERSIONING_SCHEME, DefaultAPIVersioning)
 
@@ -285,21 +277,13 @@ class TestEllarApp:
         injector = EllarInjector(
             auto_bind=False
         )  # will raise an exception is service is not registered
-        CoreServiceRegistration(injector).register_all()
+        EllarAppService(injector, config=Config()).register_core_services()
         injector.container.register_instance(config)
 
         app = App(config=config, injector=injector)
         assert injector.get(Reflector)
         assert injector.get(Config) is config
         assert injector.get(Environment) is app.jinja_environment
-        with pytest.raises(
-            Exception, match="Service Unavailable at the current context."
-        ):
-            injector.get(IExecutionContext)
-        with pytest.raises(
-            Exception, match="Service Unavailable at the current context."
-        ):
-            injector.get(IHostContext)
 
     def test_app_exception_handler(self):
         class CustomException(Exception):
@@ -311,13 +295,13 @@ class TestEllarApp:
             async def catch(
                 self, ctx: IExecutionContext, exc: t.Union[t.Any, Exception]
             ) -> t.Union[Response, t.Any]:
-                return JSONResponse(dict(detail=str(exc)), status_code=404)
+                return JSONResponse({"detail": str(exc)}, status_code=404)
 
         config = Config()
         injector = EllarInjector(
             auto_bind=False
         )  # will raise an exception is service is not registered
-        CoreServiceRegistration(injector).register_all()
+        EllarAppService(injector, config=Config()).register_core_services()
         injector.container.register_instance(config)
         app = App(config=config, injector=injector)
         app.add_exception_handler(CustomExceptionHandler())
@@ -369,8 +353,9 @@ class TestAppTemplating:
         with open(path, "w") as file:
             file.write("<file content>")
 
-        config = Config(STATIC_DIRECTORIES=[tmpdir])
-        app = App(injector=EllarInjector(), config=config)
+        app = Test.create_test_module(
+            config_module={"STATIC_DIRECTORIES": [tmpdir]}
+        ).create_application()
         static_app = app.create_static_app()
         assert isinstance(static_app, StaticFiles)
         client = TestClient(static_app)
@@ -391,8 +376,9 @@ class TestAppTemplating:
         with open(path, "w") as file:
             file.write("<file content>")
 
-        config = Config(STATIC_DIRECTORIES=[tmpdir])
-        app = App(injector=EllarInjector(), config=config)
+        app = Test.create_test_module(
+            config_module={"STATIC_DIRECTORIES": [tmpdir]}
+        ).create_application()
         static_app_old = app._static_app
 
         app.reload_static_app()
@@ -405,7 +391,7 @@ class TestAppTemplating:
         assert res.text == "<file content>"
 
     def test_app_template_filter(self):
-        app = App(injector=EllarInjector(), config=Config())
+        app = Test.create_test_module().create_application()
 
         @app.template_filter()
         def square(value):
@@ -430,7 +416,7 @@ class TestAppTemplating:
         assert result == "<html>filter square: 4, filter triple_function: 27</html>"
 
     def test_app_template_global(self):
-        app = App(injector=EllarInjector(), config=Config())
+        app = Test.create_test_module().create_application()
 
         @app.template_global()
         def square(value):
