@@ -1,13 +1,15 @@
 import os
 
 import pytest
-from pydantic.json import ENCODERS_BY_TYPE
-from starlette.responses import JSONResponse
-
-from ellar.constants import ELLAR_CONFIG_MODULE
+from ellar.common.constants import ELLAR_CONFIG_MODULE
 from ellar.core.conf import Config, ConfigDefaultTypesMixin
 from ellar.core.conf.config import ConfigRuntimeError
 from ellar.core.versioning import DefaultAPIVersioning, UrlPathAPIVersioning
+from pydantic.json import ENCODERS_BY_TYPE
+from starlette.responses import JSONResponse
+
+if ELLAR_CONFIG_MODULE in os.environ:
+    os.environ.pop(ELLAR_CONFIG_MODULE)
 
 
 class ConfigTesting(ConfigDefaultTypesMixin):
@@ -76,10 +78,10 @@ def test_configuration_raise_runtime_error_for_invalid_settings_module_path():
     with pytest.raises(ConfigRuntimeError):
         Config(config_module="tests.somewrongpath.settings")
 
-    with pytest.raises(Exception):
+    with pytest.raises(ValueError):
         Config(STATIC_FOLDER_PACKAGES=[("package",)])
 
-    with pytest.raises(Exception):
+    with pytest.raises(ValueError):
         Config(STATIC_FOLDER_PACKAGES=[("package", "static", "some_whatever")])
 
 
@@ -93,24 +95,37 @@ def test_configuration_settings_can_be_loaded_through_constructor():
     assert config.REDIRECT_SLASHES is True
     assert config.STATIC_MOUNT_PATH == "/static-changed"
 
+    config.set_defaults(
+        DEBUG=False, SECRET_KEY="your-secret-key-changed-again", NEW_KEY="Some new key"
+    )
+    assert config.DEBUG  # not changed
+    assert config.SECRET_KEY == "your-secret-key-changed"  # not changed
+    assert config.NEW_KEY == "Some new key"  # Added since its doesn't exist
+
 
 def test_configuration_can_be_changed_during_instantiation():
+    def int_encode(value):
+        pass
+
     config = Config(
         config_module=overriding_settings_path,
         DEBUG=False,
         SOME_NEW_CONFIGS="some new configuration values",
         JINJA_TEMPLATES_OPTIONS={"auto_reload": False},
+        SERIALIZER_CUSTOM_ENCODER={int: int_encode},
     )
 
     assert config.DEBUG is False
     assert config.JINJA_TEMPLATES_OPTIONS == {"auto_reload": False}
     assert config.SOME_NEW_CONFIGS == "some new configuration values"
+    assert config.SERIALIZER_CUSTOM_ENCODER[int] == int_encode
 
 
 def test_can_set_defaults_a_configuration_instance_once():
     config = Config(config_module=overriding_settings_path)
-    with pytest.raises(Exception):
-        config.SOME_NEW_CONFIGS
+    with pytest.raises(AttributeError):
+        d = config.SOME_NEW_CONFIGS
+        assert d
     config.setdefault("SOME_NEW_CONFIGS", "some new configuration values")
     assert config.SOME_NEW_CONFIGS == "some new configuration values"
 
@@ -131,12 +146,15 @@ def test_can_change_configuration_values_after_instantiation():
     config["SOME_NEW_CONFIGS"] = "some new configuration values changed"
     assert config.SOME_NEW_CONFIGS == "some new configuration values changed"
 
+    config.SOME_NEW_CONFIGS_2 = "some new configuration values changed"
+    assert config.SOME_NEW_CONFIGS_2 == "some new configuration values changed"
+
     config.config_module = "somethings"
     assert config.config_module == "somethings"
 
 
 def test_can_export_configuration_values():
     config = Config()
-    values = list(config.values)
+    values = list(config.config_values)
 
     assert len(values) > 7
