@@ -1,62 +1,63 @@
 from typing import List
 
 import pytest
-from starlette.responses import JSONResponse
-from starlette.routing import Host, Mount, Router, compile_path
-
-from ellar.core import Config
-from ellar.core.middleware import RequestVersioningMiddleware
-from ellar.core.routing import RouteOperation, WebsocketRouteOperation
-from ellar.core.routing.router import RouteCollection
+from ellar.common import Version as version_decorator
+from ellar.common import get, http_route, ws_route
+from ellar.common.constants import (
+    CONTROLLER_CLASS_KEY,
+    CONTROLLER_OPERATION_HANDLER_KEY,
+)
+from ellar.common.helper import generate_controller_operation_unique_id
+from ellar.common.routing import (
+    RouteCollection,
+    RouteOperation,
+    WebsocketRouteOperation,
+)
+from ellar.core.routing.helper import build_route_handler
 from ellar.core.versioning import UrlPathAPIVersioning
-from ellar.helper import generate_controller_operation_unique_id
-
-config = Config(VERSIONING_SCHEME=UrlPathAPIVersioning())
+from ellar.reflect import reflect
+from ellar.testing import Test
+from starlette.responses import JSONResponse
+from starlette.routing import Host, Mount
 
 
-def create_app(router):
-    return RequestVersioningMiddleware(router, debug=False, config=config)
+class Configuration:
+    VERSIONING_SCHEME = UrlPathAPIVersioning()
 
 
-class MockRouteOperation(RouteOperation):
-    def __init__(self, path: str, methods: List[str], versions: List[str] = []):
-        self.path = path
-        self.path_regex, self.path_format, self.param_convertors = compile_path(
-            self.path
-        )
-        self.methods = [method.upper() for method in methods]
-        self._versioning = versions
+config_path = "tests.test_controller.test_route_collection:Configuration"
 
-    def endpoint(self):
-        pass
 
-    async def app(self, scope, receive, send) -> None:
+def create_route_operation(
+    path: str, methods: List[str], versions: List[str] = None
+) -> RouteOperation:
+    if versions is None:
+        versions = []
+
+    @http_route(path, methods=methods)
+    @version_decorator(*versions)
+    def endpoint_sample():
         response = JSONResponse(
-            content=dict(
-                path=self.path, methods=self.methods, versioning=self._versioning
-            )
+            content={"path": path, "methods": methods, "versioning": versions}
         )
-        await response(scope, receive, send)
+        return response
 
-    def get_allowed_version(self):
-        return self._versioning
+    return build_route_handler(endpoint_sample)
 
 
-class MockWebsocketRouteOperation(WebsocketRouteOperation):
-    def __init__(self, path: str, versions: List[str] = []):
-        self.path = path
-        self._versioning = versions
+def create_ws_route_operation(
+    path: str, versions: List[str] = None
+) -> WebsocketRouteOperation:
+    if versions is None:
+        versions = []
 
-    async def app(self, scope, receive, send) -> None:
-        response = JSONResponse(
-            content=dict(
-                path=self.path, methods=self.methods, versioning=self._versioning
-            )
-        )
-        await response(scope, receive, send)
+    @ws_route(path)
+    @version_decorator(*versions)
+    def endpoint_sample():
+        response = JSONResponse(content={"path": path, "versioning": versions})
+        return response
 
-    def get_allowed_version(self):
-        return self._versioning
+    return build_route_handler(endpoint_sample)
 
 
 class MockHostRouteOperation(Host):
@@ -76,26 +77,31 @@ class MockMountRouteOperation(Mount):
 
 
 @pytest.mark.parametrize("collection_model", [RouteCollection])
-def test_module_route_collection_for_same_path_but_different_version(
-    collection_model, test_client_factory
-):
+def test_module_route_collection_for_same_path_but_different_version(collection_model):
     routes = collection_model()
-    routes.append(MockRouteOperation("/sample", methods=["post"], versions=[]))
-    routes.append(MockRouteOperation("/sample", methods=["post"], versions=["1"]))
+    routes.extend(
+        [
+            create_route_operation("/sample", methods=["post"], versions=[]),
+            create_route_operation("/sample", methods=["post"], versions=["1"]),
+        ]
+    )
     assert len(routes) == 2
     for route in routes:
         assert route.path == "/sample"
 
-    client = test_client_factory(create_app(Router(routes=routes)))
+    tm = Test.create_test_module(config_module=config_path)
+    tm.create_application().router.extend(routes)
+    client = tm.get_test_client()
+
     response = client.post("/sample")
     assert response.status_code == 200
-    assert response.json() == {"path": "/sample", "methods": ["POST"], "versioning": []}
+    assert response.json() == {"path": "/sample", "methods": ["post"], "versioning": []}
 
     response = client.post("/v1/sample")
     assert response.status_code == 200
     assert response.json() == {
         "path": "/sample",
-        "methods": ["POST"],
+        "methods": ["post"],
         "versioning": ["1"],
     }
 
@@ -105,18 +111,17 @@ def test_module_route_collection_extend(collection_model):
     routes = collection_model()
     routes.extend(
         [
-            MockRouteOperation("/sample", methods=["post"], versions=[]),
-            MockRouteOperation("/sample", methods=["post"], versions=[]),
-            MockRouteOperation("/sample", methods=["post"], versions=["1"]),
-            MockWebsocketRouteOperation("/sample", versions=["1"]),
+            create_route_operation("/sample", methods=["post"], versions=[]),
+            create_route_operation("/sample", methods=["post"], versions=[]),
+            create_route_operation("/sample", methods=["post"], versions=["1"]),
+            create_ws_route_operation("/sample", versions=["1"]),
         ]
     )
-    assert len(routes) == 3
+    assert len(routes) == 4
 
 
 @pytest.mark.parametrize("collection_model", [RouteCollection])
 def test_module_route_collection_host(collection_model):
-
     routes = collection_model()
     routes.append(MockHostRouteOperation("{subdomain}.example.org"))
     _hash = generate_controller_operation_unique_id(
@@ -159,9 +164,9 @@ def test_module_route_collection_mount(collection_model):
 )
 def test_module_route_collection_setitem_and_getitem(collection_model, expected_result):
     routes = collection_model()
-    routes[0] = MockRouteOperation("/sample/1", methods=["post"], versions=[])
-    routes[1] = MockRouteOperation("/sample", methods=["post"], versions=["1"])
-    routes[2] = MockRouteOperation("/sample/2", methods=["post"], versions=[])
+    routes[0] = create_route_operation("/sample/1", methods=["post"], versions=[])
+    routes[1] = create_route_operation("/sample", methods=["post"], versions=["1"])
+    routes[2] = create_route_operation("/sample/2", methods=["post"], versions=[])
 
     # add unknown type
     routes[3] = type("MockRouteOperation", (), {})  # this will be ignored
@@ -175,20 +180,45 @@ def test_module_route_collection_for_same_path_different_method(
     collection_model, test_client_factory
 ):
     routes = collection_model()
-    routes.append(MockRouteOperation("/sample", methods=["post"], versions=[]))
-    routes.append(MockRouteOperation("/sample", methods=["post", "get"], versions=[]))
+    routes.append(create_route_operation("/sample", methods=["post"], versions=[]))
+    routes.append(
+        create_route_operation("/sample", methods=["post", "get"], versions=[])
+    )
 
     assert len(routes) == 2
 
-    client = test_client_factory(create_app(Router(routes=routes)))
+    tm = Test.create_test_module(config_module=config_path)
+    tm.create_application().router.extend(routes)
+    client = tm.get_test_client()
+
     response = client.get("/sample")
     assert response.status_code == 200
     assert response.json() == {
         "path": "/sample",
-        "methods": ["POST", "GET"],
+        "methods": ["post", "get"],
         "versioning": [],
     }
 
     response = client.post("/sample")
     assert response.status_code == 200
-    assert response.json() == {"path": "/sample", "methods": ["POST"], "versioning": []}
+    assert response.json() == {"path": "/sample", "methods": ["post"], "versioning": []}
+
+
+@pytest.mark.parametrize("collection_model", [RouteCollection])
+def test_route_collection_create_control_type(collection_model):
+    @get()
+    def endpoint_once():
+        pass
+
+    assert reflect.get_metadata(CONTROLLER_CLASS_KEY, endpoint_once) is None
+    operation = reflect.get_metadata(CONTROLLER_OPERATION_HANDLER_KEY, endpoint_once)
+
+    collection_model([operation])
+    assert not isinstance(
+        reflect.get_metadata(CONTROLLER_CLASS_KEY, endpoint_once), list
+    )
+
+    collection_model([operation])
+    assert not isinstance(
+        reflect.get_metadata(CONTROLLER_CLASS_KEY, endpoint_once), list
+    )
