@@ -1,7 +1,7 @@
 from abc import ABC, abstractmethod
 
 from ellar.di import injectable
-from ellar.di.scopes import RequestScope, TransientScope
+from ellar.di.scopes import RequestORTransientScope, RequestScope, TransientScope
 
 
 class Foo:
@@ -45,12 +45,15 @@ class IRepository(ABC):
 
 
 class IDBContext(ABC):
-    pass
+    @abstractmethod
+    def context(self):
+        pass
 
 
 @injectable
 class AnyDBContext(IDBContext):
-    pass
+    def context(self):
+        pass
 
 
 @injectable
@@ -86,3 +89,17 @@ class AnyContext(IContext):
     @property
     def user(self):
         return "Example"
+
+
+@injectable(RequestORTransientScope)
+class TransientRequestContext(IContext):
+    def __init__(self):
+        pass
+
+    @property
+    def id(self):
+        return "Example"
+
+    @property
+    def user(self):
+        return "Example"
