@@ -1,14 +1,12 @@
 from collections import OrderedDict
 
 import pytest
-from injector import Binder, Injector, UnsatisfiedRequirement
-
 from ellar.common import Module
-from ellar.constants import ASGI_CONTEXT_VAR, MODULE_REF_TYPES
 from ellar.core import Config, ModuleBase
 from ellar.core.modules.ref import create_module_ref_factor
-from ellar.di import Container, EllarInjector
+from ellar.di import MODULE_REF_TYPES, SCOPED_CONTEXT_VAR, Container, EllarInjector
 from ellar.di.providers import ClassProvider, InstanceProvider
+from injector import Binder, Injector, UnsatisfiedRequirement
 
 from .examples import Foo, Foo1, Foo2
 
@@ -22,29 +20,57 @@ class EllarTestTemplateModule(ModuleBase):
     pass
 
 
-def test_container_install_module():
+def test_container_install_module_case_1():
     called = False
     app_container = EllarInjector().container
 
-    class FakeModule(ModuleBase):
+    class PlainModule(ModuleBase):
         def register_services(self, container: Container) -> None:
             nonlocal called
             called = True
 
+    @Module()
+    class DecoratedModuleWithBase(ModuleBase):
+        def register_services(self, container: Container) -> None:
+            nonlocal called
+            called = True
+
+    plain_module = app_container.install(PlainModule)
+    assert called
+    assert isinstance(plain_module, PlainModule)
+
+    called = False
+
+    decorated_module = app_container.install(DecoratedModuleWithBase)
+    assert called
+    assert isinstance(decorated_module, DecoratedModuleWithBase)
+
+    called = False
+    app_container.install(PlainModule())
+    assert called
+
+    called = False
+
+    app_container.install(DecoratedModuleWithBase())
+    assert called
+
+
+def test_container_install_module_return_case_2():
+    called = False
+    app_container = EllarInjector().container
+
     @Module()
     class DecoratedModule:
         def register_services(self, container: Container) -> None:
             nonlocal called
             called = True
 
-    fake_module = app_container.install(FakeModule)
-    assert called
-    assert isinstance(fake_module, FakeModule)
-
-    called = False
-
     decorated_module = app_container.install(DecoratedModule)
-    assert called
+    assert called is False
+    assert isinstance(decorated_module, DecoratedModule)
+
+    decorated_module = app_container.install(DecoratedModule())
+    assert called is False
     assert isinstance(decorated_module, DecoratedModule)
 
 
@@ -67,16 +93,8 @@ async def test_request_service_context():
     injector.container.register_scoped(Foo1)
     injector.container.register_exact_transient(Foo2)
 
-    def assert_attributes():
-        asgi_context_var = ASGI_CONTEXT_VAR.get()
-        assert len(asgi_context_var.context) == 0
-        assert len(asgi_context_var.scope) == 0
-        assert asgi_context_var.receive is None
-        assert asgi_context_var.send is None
-
-    async with injector.create_asgi_args({}, None, None):
-        assert_attributes()
-        asgi_context = ASGI_CONTEXT_VAR.get()
+    async with injector.create_asgi_args():
+        asgi_context = SCOPED_CONTEXT_VAR.get()
 
         foo1 = injector.get(Foo1)  # result will be tracked by asgi_context
         injector.get(Foo2)  # registered as transient scoped
@@ -94,15 +112,16 @@ async def test_request_service_context():
         with pytest.raises(UnsatisfiedRequirement):
             injector.get(Foo)
 
-    assert injector.get(Foo1) != foo1
+    with pytest.raises(UnsatisfiedRequirement):
+        injector.get(Foo1)
 
 
 @pytest.mark.asyncio
 async def test_injector_update_scoped_context():
     injector = EllarInjector(auto_bind=False)
 
-    async with injector.create_asgi_args({}, None, None):
-        asgi_context = ASGI_CONTEXT_VAR.get()
+    async with injector.create_asgi_args():
+        asgi_context = SCOPED_CONTEXT_VAR.get()
 
         injector.update_scoped_context(Foo1, Foo1())
         injector.update_scoped_context(Foo, ClassProvider(Foo))
@@ -111,11 +130,11 @@ async def test_injector_update_scoped_context():
         assert isinstance(asgi_context.context[Foo], ClassProvider)
 
     injector.update_scoped_context(Foo1, Foo1())
-    assert ASGI_CONTEXT_VAR.get() is None
+    assert SCOPED_CONTEXT_VAR.get() is None
 
 
 class TestInjectorModuleFunctions:
-    def setup(self):
+    def setup_method(self):
         self.injector = EllarInjector()
         config = Config()
 
