@@ -1,10 +1,8 @@
 import http
 
 import pytest
-
 from ellar.common import get
-from ellar.core import TestClientFactory
-from ellar.core.exceptions import (
+from ellar.common.exceptions import (
     APIException,
     AuthenticationFailed,
     MethodNotAllowed,
@@ -14,10 +12,11 @@ from ellar.core.exceptions import (
     PermissionDenied,
     UnsupportedMediaType,
 )
+from ellar.testing import Test
 
 from .exception_runner import ExceptionRunner
 
-test_module = TestClientFactory.create_test_module()
+test_module = Test.create_test_module()
 
 
 _exception_runner = ExceptionRunner(APIException)
@@ -28,8 +27,8 @@ def exception_():
     _exception_runner.run()
 
 
-test_module.app.router.append(exception_)
-client = test_module.get_client()
+test_module.create_application().router.append(exception_)
+client = test_module.get_test_client()
 
 
 @pytest.mark.parametrize(
@@ -88,3 +87,22 @@ def test_method_not_allowed_api_exception():
     data = response.json()
     assert response.status_code == MethodNotAllowed.status_code
     assert data["detail"] == http.HTTPStatus(MethodNotAllowed.status_code).phrase
+
+
+def test_api_exception_details():
+    exc = APIException(
+        detail="Some error details", description="Some error description"
+    )
+    assert exc.get_details() == {
+        "description": "Some error description",
+        "detail": "Some error details",
+    }
+
+
+def test_api_exception_full_details():
+    exc = APIException(detail="Some error details")
+    assert exc.get_full_details() == {
+        "code": "bad_request",
+        "description": "Bad request syntax or unsupported method",
+        "detail": "Some error details",
+    }
