@@ -1,34 +1,35 @@
-import pytest
-from starlette.routing import Route
+import logging
 
+import pytest
+from ellar.app import AppFactory
 from ellar.common import (
     Module,
     exception_handler,
     middleware,
-    on_shutdown,
-    on_startup,
     template_filter,
     template_global,
 )
-from ellar.constants import (
+from ellar.common.constants import (
     EXCEPTION_HANDLERS_KEY,
     MIDDLEWARE_HANDLERS_KEY,
     MODULE_METADATA,
-    ON_REQUEST_SHUTDOWN_KEY,
-    ON_REQUEST_STARTUP_KEY,
     TEMPLATE_FILTER_KEY,
     TEMPLATE_GLOBAL_KEY,
 )
-from ellar.core import AppFactory, Config, ModuleBase, TestClientFactory
+from ellar.common.helper import get_name
+from ellar.core import Config, ModuleBase
 from ellar.core.modules.ref import (
+    InvalidModuleTypeException,
     ModulePlainRef,
     ModuleProvider,
     ModuleTemplateRef,
     create_module_ref_factor,
 )
 from ellar.di import EllarInjector, TransientScope, injectable
-from ellar.helper import get_name
 from ellar.reflect import reflect
+from ellar.testing import Test
+from injector import UnsatisfiedRequirement
+from starlette.routing import Route
 
 from .sample import AnotherUserService, ModuleBaseExample, SampleController, UserService
 
@@ -57,7 +58,6 @@ class NonTemplateModuleExample(ModuleBase):
 
 
 def test_create_module_ref_factor_creates_right_module_ref():
-
     config = Config()
     container = EllarInjector(auto_bind=False).container
 
@@ -65,13 +65,13 @@ def test_create_module_ref_factor_creates_right_module_ref():
         NonTemplateModuleExample, config=config, container=container, a="a", b="b"
     )
     assert isinstance(module_ref, ModulePlainRef)
-    assert module_ref._init_kwargs == dict(a="a", b="b")
+    assert module_ref._init_kwargs == {"a": "a", "b": "b"}
 
     module_ref = create_module_ref_factor(
         ModuleBaseExample, config=config, container=container
     )
     assert isinstance(module_ref, ModuleTemplateRef)
-    assert module_ref._init_kwargs == dict()
+    assert module_ref._init_kwargs == {}
 
 
 def test_module_init_kwargs_build_correctly():
@@ -81,16 +81,13 @@ def test_module_init_kwargs_build_correctly():
         InitKwargsModule, config=config, container=container
     )
     assert module_ref
-    assert module_ref._init_kwargs == dict(d=12.3, c="C")
+    assert module_ref._init_kwargs == {"d": 12.3, "c": "C"}
 
 
 def test_module_ref_registers_module_type():
     config = Config()
     container = EllarInjector(auto_bind=False).container
 
-    with pytest.raises(Exception):
-        container.injector.get(ModuleBaseExample)
-
     create_module_ref_factor(ModuleBaseExample, config=config, container=container)
     create_module_ref_factor(ModuleProviderTest, config=config, container=container)
 
@@ -140,36 +137,6 @@ def test_module_template_ref_template_filters():
     assert "some_template_filter" in template_filter_functions
 
 
-def test_module_template_ref_scan_starlette_app_events():
-    @Module()
-    class RouterEventsModuleExample:
-        @on_startup
-        async def on_startup_handler(cls):
-            pass
-
-        @on_shutdown
-        def on_shutdown_handler(cls):
-            pass
-
-    config = Config()
-    container = EllarInjector(auto_bind=False).container
-
-    request_startup = config[ON_REQUEST_STARTUP_KEY]
-    request_shutdown = config[ON_REQUEST_SHUTDOWN_KEY]
-
-    assert len(request_startup) == 0 and len(request_shutdown) == 0
-
-    create_module_ref_factor(
-        RouterEventsModuleExample, config=config, container=container
-    )
-    request_startup = config[ON_REQUEST_STARTUP_KEY]
-    request_shutdown = config[ON_REQUEST_SHUTDOWN_KEY]
-
-    assert isinstance(request_startup, list) and isinstance(request_shutdown, list)
-    assert "on_startup_handler" == get_name(request_startup[0].handler)
-    assert "on_shutdown_handler" == get_name(request_shutdown[0].handler)
-
-
 def test_module_template_ref_scan_exceptions_handlers():
     @Module()
     class ModuleExceptionHandlerSample(ModuleBase):
@@ -232,20 +199,38 @@ def test_module_template_ref_get_all_routers():
     assert len(module_ref.routers) == 5
 
 
-def test_module_template_ref_get_all_routers_fails_for_invalid_controller():
+def test_module_template_ref_get_all_routers_fails_for_invalid_controller(caplog):
     some_invalid_controller = type("SomeInvalidController", (), {})
     with reflect.context():
         reflect.define_metadata(
-            MODULE_METADATA.CONTROLLERS, some_invalid_controller, ModuleBaseExample
+            MODULE_METADATA.CONTROLLERS, [some_invalid_controller], ModuleBaseExample
         )
         config = Config()
         container = EllarInjector(auto_bind=False).container
 
-        with pytest.raises(AssertionError, match="Invalid Controller Type."):
+        with caplog.at_level(logging.WARNING):
             create_module_ref_factor(
                 ModuleBaseExample, config=config, container=container
             )
 
+        assert (
+            "Router Factory Builder was not found.\nUse `ControllerRouterBuilderFactory` "
+            "as an example create a FactoryBuilder for this type: <class 'type'>"
+            in str(caplog.text)
+        )
+
+
+def test_invalid_module_template_ref():
+    config = Config()
+    container = EllarInjector(auto_bind=False).container
+
+    invalid_module = type("InvalidModule", (), {})
+    with pytest.raises(
+        InvalidModuleTypeException,
+        match="must be a subclass of `ellar.core.ModuleBase`",
+    ):
+        create_module_ref_factor(invalid_module, config=config, container=container)
+
 
 def test_module_plain_ref_routes_return_empty_list():
     config = Config()
@@ -255,6 +240,7 @@ def test_module_plain_ref_routes_return_empty_list():
         NonTemplateModuleExample, config=config, container=container
     )
     assert module_ref.routes == []
+    assert isinstance(module_ref.config, Config)
 
 
 def test_module_template_ref_routes_returns_valid_routes():
@@ -270,8 +256,11 @@ def test_module_template_ref_routes_returns_valid_routes():
         module_ref = create_module_ref_factor(
             ModuleBaseExample, config=config, container=container
         )
+
+        app = AppFactory.create_from_app_module(module=ModuleBaseExample)
     assert len(module_ref.routers) == 4
-    assert len(module_ref.routes) == 3
+    assert len(module_ref.routes) == 4
+    assert len(app.routes) == 3
 
 
 def test_module_template_ref_routes():
@@ -290,13 +279,13 @@ def test_module_template_registers_providers_and_controllers():
     config = Config()
     container = EllarInjector(auto_bind=False).container
 
-    with pytest.raises(Exception):
+    with pytest.raises(UnsatisfiedRequirement):
         container.injector.get(UserService)
 
-    with pytest.raises(Exception):
+    with pytest.raises(UnsatisfiedRequirement):
         container.injector.get(AnotherUserService)
 
-    with pytest.raises(Exception):
+    with pytest.raises(UnsatisfiedRequirement):
         container.injector.get(SampleController)
 
     module_ref = create_module_ref_factor(
@@ -313,46 +302,13 @@ def test_run_application_ready_works():
     @Module()
     class TestModuleCycleExample(ModuleBase):
         _before_init_called = False
-        _app_ready_called = False
 
         @classmethod
         def before_init(cls, config: Config) -> None:
             cls._before_init_called = True
 
-        def application_ready(self, app) -> None:
-            self.__class__._app_ready_called = True
-
     assert TestModuleCycleExample._before_init_called is False
-    assert TestModuleCycleExample._app_ready_called is False
 
-    AppFactory.create_from_app_module(TestModuleCycleExample)
+    Test.create_test_module(modules=[TestModuleCycleExample]).create_application()
 
     assert TestModuleCycleExample._before_init_called
-    assert TestModuleCycleExample._app_ready_called
-
-
-def test_module_request_events():
-    @Module()
-    class RouterEventsModuleExample:
-        _on_shutdown_handler_called = False
-        _on_startup_handler_called = False
-
-        @on_startup
-        async def on_startup_handler(cls):
-            cls._on_startup_handler_called = True
-
-        @on_shutdown
-        def on_shutdown_handler(cls):
-            cls._on_shutdown_handler_called = True
-
-    assert RouterEventsModuleExample._on_shutdown_handler_called is False
-    assert RouterEventsModuleExample._on_startup_handler_called is False
-
-    tm = TestClientFactory.create_test_module_from_module(RouterEventsModuleExample)
-
-    test_client = tm.get_client()
-    with test_client as client:
-        client.get("/")
-
-    assert RouterEventsModuleExample._on_shutdown_handler_called
-    assert RouterEventsModuleExample._on_startup_handler_called
