@@ -1,19 +1,26 @@
 from typing import List, Union
 
 import pytest
-from starlette.responses import JSONResponse
-
-from ellar.core.response.model import (
+from ellar.common.constants import RESPONSE_OVERRIDE_KEY
+from ellar.common.exceptions import ImproperConfiguration
+from ellar.common.responses.models import (
     EmptyAPIResponseModel,
     JSONResponseModel,
     ResponseModel,
     RouteResponseExecution,
     RouteResponseModel,
 )
+from ellar.common.routing import RouteOperation
+from ellar.reflect import reflect
+from starlette.responses import JSONResponse
 
 from ..schema import BlogObjectDTO, NoteSchemaDC
 
 
+def endpoint_sample():
+    pass  # pragma: no cover
+
+
 class JsonApiResponse(JSONResponse):
     media_type = "application/vnd.api+json"
 
@@ -90,9 +97,9 @@ def test_route_response_model(
 @pytest.mark.parametrize(
     "inputs",
     [
-        list(),
+        [],
         set(),
-        tuple(),
+        (),
         ResponseModel,
         JsonApiResponseModel,
         EmptyAPIResponseModel,
@@ -101,3 +108,17 @@ def test_route_response_model(
 def test_route_response_model_exception(inputs):
     with pytest.raises(RouteResponseExecution):
         RouteResponseModel(route_responses=inputs)
+
+
+def test_invalid_response_override_definition():
+    reflect.define_metadata(
+        RESPONSE_OVERRIDE_KEY, {EmptyAPIResponseModel()}, endpoint_sample
+    )
+    with pytest.raises(ImproperConfiguration) as ex:
+        RouteOperation(
+            path="/",
+            methods=["get"],
+            endpoint=endpoint_sample,
+            response={200: EmptyAPIResponseModel()},
+        )
+    assert "`RESPONSE_OVERRIDE` is must be of type `Dict`" in str(ex)
