@@ -1,12 +1,10 @@
 import pytest
-
-from ellar.common import Cookie, get
-from ellar.core import TestClientFactory
+from ellar.common import Cookie, Inject, ModuleRouter, get, serialize_object
+from ellar.common.exceptions import ImproperConfiguration
 from ellar.core.connection import Request
-from ellar.core.exceptions import ImproperConfiguration
-from ellar.core.routing import ModuleRouter
+from ellar.core.routing.helper import build_route_handler
 from ellar.openapi import OpenAPIDocumentBuilder
-from ellar.serializer import serialize_object
+from ellar.testing import Test
 
 from .sample import Data, Filter, ListOfPrimitiveSchema, NonPrimitiveSchema
 
@@ -15,7 +13,7 @@ router = ModuleRouter("")
 
 @router.get("/test/cookie")
 def cookie_params_schema(
-    request: Request,
+    request: Inject[Request],
     filters: Filter = Cookie(..., alias="will_not_work_for_schema_with_many_field"),
 ):
     return filters.dict()
@@ -23,18 +21,19 @@ def cookie_params_schema(
 
 @router.get("/test-mixed/cookie")
 def cookie_params_mixed_schema(
-    request: Request,
-    filters: Filter = Cookie(...),
-    data: Data = Cookie(...),
+    request: Inject[Request],
+    filters: Cookie[Filter],
+    data: Cookie[Data],
 ):
-    return dict(filters=filters.dict(), data=data.dict())
+    return {"filters": filters.dict(), "data": data.dict()}
 
 
-tm = TestClientFactory.create_test_module(routers=(router,))
+tm = Test.create_test_module(routers=(router,))
+app = tm.create_application()
 
 
 def test_cookie_request():
-    client = tm.get_client()
+    client = tm.get_test_client()
     response = client.get(
         "/test/cookie",
         cookies={"from": "1", "to": "2", "range": "20", "foo": "1", "range2": "50"},
@@ -53,7 +52,7 @@ def test_cookie_request():
 
 
 def test_cookie_request_mixed():
-    client = tm.get_client()
+    client = tm.get_test_client()
     response = client.get(
         "/test-mixed/cookie",
         cookies={
@@ -83,18 +82,28 @@ def test_cookie_request_mixed():
 
 
 def test_cookie_schema():
-    document = serialize_object(OpenAPIDocumentBuilder().build_document(tm.app))
+    document = serialize_object(OpenAPIDocumentBuilder().build_document(app))
     params = document["paths"]["/test/cookie"]["get"]["parameters"]
     assert params == [
         {
             "required": False,
-            "schema": {"title": "To", "type": "string", "format": "date-time"},
+            "schema": {
+                "title": "To",
+                "type": "string",
+                "format": "date-time",
+                "include_in_schema": True,
+            },
             "name": "to",
             "in": "cookie",
         },
         {
             "required": False,
-            "schema": {"title": "From", "type": "string", "format": "date-time"},
+            "schema": {
+                "title": "From",
+                "type": "string",
+                "format": "date-time",
+                "include_in_schema": True,
+            },
             "name": "from",
             "in": "cookie",
         },
@@ -103,6 +112,7 @@ def test_cookie_schema():
             "schema": {
                 "allOf": [{"$ref": "#/components/schemas/Range"}],
                 "default": 20,
+                "include_in_schema": True,
             },
             "name": "range",
             "in": "cookie",
@@ -117,6 +127,8 @@ def test_invalid_schema_cookie():
         def invalid_path_parameter(cookie: NonPrimitiveSchema = Cookie()):
             pass
 
+        build_route_handler(invalid_path_parameter)
+
     assert (
         str(ex.value)
         == "field: 'filter' with annotation:'<class 'tests.test_routing.sample.Filter'>' in "
@@ -130,6 +142,8 @@ def test_invalid_schema_cookie():
         def invalid_path_parameter(cookie: ListOfPrimitiveSchema = Cookie()):
             pass
 
+        build_route_handler(invalid_path_parameter)
+
     assert (
         str(ex.value) == "field: 'an_int' with annotation:'typing.List[int]' in "
         "'<class 'tests.test_routing.sample.ListOfPrimitiveSchema'>'can't be processed. "
