@@ -1,19 +1,17 @@
 from functools import wraps
 
-from starlette.responses import Response
-
-from ellar.common import Provide, Query, get, set_metadata
-from ellar.constants import EXTRA_ROUTE_ARGS_KEY
-from ellar.core import TestClientFactory
+from ellar.common import IExecutionContext, Inject, Query, extra_args, get
+from ellar.common.params import ExtraEndpointArg
+from ellar.common.serializer import serialize_object
 from ellar.core.connection import Request
-from ellar.core.context import IExecutionContext
-from ellar.core.params import ExtraEndpointArg
 from ellar.openapi import OpenAPIDocumentBuilder
-from ellar.serializer import serialize_object
+from ellar.testing import Test
+from starlette.responses import Response
 
 from .sample import Filter
 
-tm = TestClientFactory.create_test_module()
+tm = Test.create_test_module()
+app = tm.create_application()
 
 
 def add_additional_signature_to_endpoint(func):
@@ -22,12 +20,14 @@ def add_additional_signature_to_endpoint(func):
     query2 = ExtraEndpointArg(
         name="query2", annotation=str
     )  # will default to Query during computation
-    extra_args = [query1, query2]
-    set_metadata(EXTRA_ROUTE_ARGS_KEY, extra_args)(func)
+
+    extra_args(query1, query2)(func)
 
     @wraps(func)
     def _wrapper(*args, **kwargs):
         # RESOLVING EXTRA ARGS
+        # All extra args must be resolved before calling route function
+        # else extra argument will be pushed to the route function
         resolved_query1 = query1.resolve(kwargs)
         resolved_query2 = query2.resolve(kwargs)
 
@@ -41,14 +41,14 @@ def add_additional_signature_to_endpoint(func):
 def add_extra_non_field_extra_args(func):
     # EXTRA ARGS SETUP
     context = ExtraEndpointArg(
-        name="context", annotation=IExecutionContext, default_value=Provide()
+        name="context", annotation=Inject[IExecutionContext], default_value=None
     )
     response = ExtraEndpointArg(
-        name="response", annotation=Response, default_value=Provide()
+        name="response", annotation=Inject[Response], default_value=None
     )
 
-    set_metadata(EXTRA_ROUTE_ARGS_KEY, response)(func)
-    set_metadata(EXTRA_ROUTE_ARGS_KEY, context)(func)
+    extra_args(response)(func)
+    extra_args(context)(func)
 
     @wraps(func)
     def _wrapper(*args, **kwargs):
@@ -67,13 +67,13 @@ def add_extra_non_field_extra_args(func):
 @add_extra_non_field_extra_args
 @add_additional_signature_to_endpoint
 def query_params_extra(
-    request: Request,
+    request: Inject[Request],
     filters: Filter = Query(),
 ):
     return filters.dict()
 
 
-tm.app.router.append(query_params_extra)
+app.router.append(query_params_extra)
 
 openapi_schema = {
     "openapi": "3.0.2",
@@ -89,6 +89,7 @@ openapi_schema = {
                             "title": "To",
                             "type": "string",
                             "format": "date-time",
+                            "include_in_schema": True,
                         },
                         "name": "to",
                         "in": "query",
@@ -99,6 +100,7 @@ openapi_schema = {
                             "title": "From",
                             "type": "string",
                             "format": "date-time",
+                            "include_in_schema": True,
                         },
                         "name": "from",
                         "in": "query",
@@ -108,19 +110,28 @@ openapi_schema = {
                         "schema": {
                             "allOf": [{"$ref": "#/components/schemas/Range"}],
                             "default": 20,
+                            "include_in_schema": True,
                         },
                         "name": "range",
                         "in": "query",
                     },
                     {
                         "required": True,
-                        "schema": {"title": "Query1", "type": "string"},
+                        "schema": {
+                            "title": "Query1",
+                            "type": "string",
+                            "include_in_schema": True,
+                        },
                         "name": "query1",
                         "in": "query",
                     },
                     {
                         "required": True,
-                        "schema": {"title": "Query2", "type": "string"},
+                        "schema": {
+                            "title": "Query2",
+                            "type": "string",
+                            "include_in_schema": True,
+                        },
                         "name": "query2",
                         "in": "query",
                     },
@@ -189,12 +200,12 @@ openapi_schema = {
 
 
 def test_openapi_schema():
-    document = serialize_object(OpenAPIDocumentBuilder().build_document(tm.app))
+    document = serialize_object(OpenAPIDocumentBuilder().build_document(app))
     assert document == openapi_schema
 
 
 def test_query_params_extra():
-    client = tm.get_client()
+    client = tm.get_test_client()
     response = client.get(
         "/test?from=1&to=2&range=20&foo=1&range2=50&query1=somequery1&query2=somequery2"
     )
