@@ -1,6 +1,8 @@
-from ellar.common import Form
-from ellar.core import TestClientFactory
-from ellar.core.routing import ModuleRouter
+from unittest.mock import patch
+
+from ellar.common import Form, ModuleRouter
+from ellar.core import Request
+from ellar.testing import Test
 
 router = ModuleRouter("")
 
@@ -20,8 +22,13 @@ def post_form_param_tuple(items: tuple = Form(...)):
     return items
 
 
-tm = TestClientFactory.create_test_module(routers=(router,))
-client = tm.get_client()
+@router.post("/form/python-tuple-failed")
+def cause_form_to_fail(items: tuple = Form(...)):
+    return items
+
+
+tm = Test.create_test_module(routers=(router,))
+client = tm.get_test_client()
 
 
 def test_python_list_param_as_form():
@@ -46,3 +53,19 @@ def test_python_tuple_param_as_form():
     )
     assert response.status_code == 200, response.text
     assert response.json() == ["first", "second", "third"]
+
+
+@patch.object(Request, "form")
+def test_form_resolution_fails(mock_form):
+    async def raise_exception():
+        raise Exception()
+
+    mock_form.return_value = raise_exception
+    response = client.post(
+        "/form/python-tuple-failed", data={"items": ["first", "second", "third"]}
+    )
+    assert response.status_code == 400
+    assert response.json() == {
+        "detail": "There was an error parsing the body",
+        "status_code": 400,
+    }
