@@ -1,6 +1,6 @@
-from ellar.common import Form
-from ellar.core import AppFactory, TestClient
-from ellar.core.routing import ModuleRouter
+from ellar.app import AppFactory
+from ellar.common import Form, ModuleRouter
+from ellar.testing import TestClient
 
 mr = ModuleRouter("")
 
