@@ -1,12 +1,10 @@
 import pytest
-
-from ellar.common import Header, get
-from ellar.core import TestClientFactory
+from ellar.common import Header, Inject, ModuleRouter, get, serialize_object
+from ellar.common.exceptions import ImproperConfiguration
 from ellar.core.connection import Request
-from ellar.core.exceptions import ImproperConfiguration
-from ellar.core.routing import ModuleRouter
+from ellar.core.routing.helper import build_route_handler
 from ellar.openapi import OpenAPIDocumentBuilder
-from ellar.serializer import serialize_object
+from ellar.testing import Test
 
 from .sample import Data, Filter, NonPrimitiveSchema
 
@@ -15,7 +13,7 @@ mr = ModuleRouter("")
 
 @mr.get("/test/header")
 def header_params_schema(
-    request: Request,
+    request: Inject[Request],
     filters: Filter = Header(..., alias="will_not_work_for_schema_with_many_field"),
 ):
     return filters.dict()
@@ -23,18 +21,19 @@ def header_params_schema(
 
 @mr.get("/test-mixed/header")
 def header_params_mixed_schema(
-    request: Request,
-    filters: Filter = Header(...),
-    data: Data = Header(...),
+    request: Inject[Request],
+    filters: Header[Filter],
+    data: Header[Data],
 ):
-    return dict(filters=filters.dict(), data=data.dict())
+    return {"filters": filters.dict(), "data": data.dict()}
 
 
-tm = TestClientFactory.create_test_module(routers=(mr,))
+tm = Test.create_test_module(routers=(mr,))
+app = tm.create_application()
 
 
 def test_header_request():
-    client = tm.get_client()
+    client = tm.get_test_client()
     response = client.get(
         "/test/header",
         headers={"from": "1", "to": "2", "range": "20", "foo": "1", "range2": "50"},
@@ -53,7 +52,7 @@ def test_header_request():
 
 
 def test_request_mixed():
-    client = tm.get_client()
+    client = tm.get_test_client()
     response = client.get(
         "/test-mixed/header",
         headers={
@@ -83,18 +82,28 @@ def test_request_mixed():
 
 
 def test_header_schema():
-    document = serialize_object(OpenAPIDocumentBuilder().build_document(tm.app))
+    document = serialize_object(OpenAPIDocumentBuilder().build_document(app))
     params = document["paths"]["/test/header"]["get"]["parameters"]
     assert params == [
         {
             "required": False,
-            "schema": {"title": "To", "type": "string", "format": "date-time"},
+            "schema": {
+                "title": "To",
+                "type": "string",
+                "format": "date-time",
+                "include_in_schema": True,
+            },
             "name": "to",
             "in": "header",
         },
         {
             "required": False,
-            "schema": {"title": "From", "type": "string", "format": "date-time"},
+            "schema": {
+                "title": "From",
+                "type": "string",
+                "format": "date-time",
+                "include_in_schema": True,
+            },
             "name": "from",
             "in": "header",
         },
@@ -103,6 +112,7 @@ def test_header_schema():
             "schema": {
                 "allOf": [{"$ref": "#/components/schemas/Range"}],
                 "default": 20,
+                "include_in_schema": True,
             },
             "name": "range",
             "in": "header",
@@ -117,6 +127,8 @@ def test_invalid_schema_header():
         def invalid_path_parameter(cookie: NonPrimitiveSchema = Header()):
             pass
 
+        build_route_handler(invalid_path_parameter)
+
     assert (
         str(ex.value)
         == "field: 'filter' with annotation:'<class 'tests.test_routing.sample.Filter'>' in "
