@@ -1,12 +1,11 @@
 from typing import Dict, List, Optional, Tuple
 
 import pytest
+from ellar.common import Header, ModuleRouter, Query
+from ellar.common.exceptions import ImproperConfiguration
+from ellar.core.routing import ModuleRouterFactory
 from pydantic import BaseModel
 
-from ellar.common import Header, Query
-from ellar.core.exceptions import ImproperConfiguration
-from ellar.core.routing import ModuleRouter
-
 mr = ModuleRouter("")
 
 
@@ -26,6 +25,8 @@ def test_invalid_sequence(field_parameter):
         def read_items(q: List[Item] = field_parameter):
             pass  # pragma: no cover
 
+        ModuleRouterFactory.build(mr)
+
 
 @pytest.mark.parametrize("field_parameter", [Query(None), Header(None)])
 def test_invalid_tuple(field_parameter):
@@ -35,6 +36,8 @@ def test_invalid_tuple(field_parameter):
         def read_items(q: Tuple[Item, Item] = field_parameter):
             pass  # pragma: no cover
 
+        ModuleRouterFactory.build(mr)
+
 
 @pytest.mark.parametrize("field_parameter", [Query(None), Header(None)])
 def test_invalid_dict(field_parameter):
@@ -44,6 +47,8 @@ def test_invalid_dict(field_parameter):
         def read_items(q: Dict[str, Item] = field_parameter):
             pass  # pragma: no cover
 
+        ModuleRouterFactory.build(mr)
+
 
 @pytest.mark.parametrize("field_parameter", [Query(None), Header(None)])
 def test_invalid_simple_dict(field_parameter):
@@ -53,6 +58,8 @@ def test_invalid_simple_dict(field_parameter):
         def read_items(q: Optional[dict] = field_parameter):
             pass  # pragma: no cover
 
+        ModuleRouterFactory.build(mr)
+
 
 @pytest.mark.parametrize("field_parameter", [Query(None), Header(None)])
 def test_invalid_group_type(field_parameter):
@@ -61,3 +68,5 @@ def test_invalid_group_type(field_parameter):
         @mr.get("/items/")
         def read_items(q: Item2 = field_parameter):
             pass  # pragma: no cover
+
+        ModuleRouterFactory.build(mr)
