@@ -1,6 +1,5 @@
 import pytest
-
-from ellar.core.testclient import TestClient
+from ellar.testing import TestClient
 
 from ..main import app
 
