@@ -1,12 +1,10 @@
 import pytest
-
-from ellar.common import Query, get
-from ellar.core import TestClientFactory
+from ellar.common import Inject, ModuleRouter, Query, get, serialize_object
+from ellar.common.exceptions import ImproperConfiguration
 from ellar.core.connection import Request
-from ellar.core.exceptions import ImproperConfiguration
-from ellar.core.routing import ModuleRouter
+from ellar.core.routing.helper import build_route_handler
 from ellar.openapi import OpenAPIDocumentBuilder
-from ellar.serializer import serialize_object
+from ellar.testing import Test
 
 from .sample import Data, Filter, NonPrimitiveSchema
 
@@ -15,7 +13,7 @@ mr = ModuleRouter("")
 
 @mr.get("/test")
 def query_params_schema(
-    request: Request,
+    request: Inject[Request],
     filters: Filter = Query(..., alias="will_not_work_for_schema_with_many_field"),
 ):
     return filters.dict()
@@ -23,20 +21,26 @@ def query_params_schema(
 
 @mr.get("/test-mixed")
 def query_params_mixed_schema(
-    request: Request,
+    request: Inject[Request],
+    filters: Query[Filter],
+    data: Query[Data],
     query1: int,
     query2: int = 5,
-    filters: Filter = Query(...),
-    data: Data = Query(...),
 ):
-    return dict(query1=query1, query2=query2, filters=filters.dict(), data=data.dict())
+    return {
+        "query1": query1,
+        "query2": query2,
+        "filters": filters.dict(),
+        "data": data.dict(),
+    }
 
 
-tm = TestClientFactory.create_test_module(routers=(mr,))
+tm = Test.create_test_module(routers=(mr,))
+app = tm.create_application()
 
 
 def test_request():
-    client = tm.get_client()
+    client = tm.get_test_client()
     response = client.get("/test?from=1&to=2&range=20&foo=1&range2=50")
     assert response.json() == {
         "to_datetime": "1970-01-01T00:00:02+00:00",
@@ -49,7 +53,7 @@ def test_request():
 
 
 def test_request_mixed():
-    client = tm.get_client()
+    client = tm.get_test_client()
     response = client.get(
         "/test-mixed?from=1&to=2&range=20&foo=1&range2=50&query1=2&int=3&float=1.6"
     )
@@ -83,18 +87,28 @@ def test_request_mixed():
 
 
 def test_schema():
-    document = serialize_object(OpenAPIDocumentBuilder().build_document(tm.app))
+    document = serialize_object(OpenAPIDocumentBuilder().build_document(app))
     params = document["paths"]["/test"]["get"]["parameters"]
     assert params == [
         {
             "required": False,
-            "schema": {"title": "To", "type": "string", "format": "date-time"},
+            "schema": {
+                "title": "To",
+                "type": "string",
+                "format": "date-time",
+                "include_in_schema": True,
+            },
             "name": "to",
             "in": "query",
         },
         {
             "required": False,
-            "schema": {"title": "From", "type": "string", "format": "date-time"},
+            "schema": {
+                "title": "From",
+                "type": "string",
+                "format": "date-time",
+                "include_in_schema": True,
+            },
             "name": "from",
             "in": "query",
         },
@@ -103,6 +117,7 @@ def test_schema():
             "schema": {
                 "allOf": [{"$ref": "#/components/schemas/Range"}],
                 "default": 20,
+                "include_in_schema": True,
             },
             "name": "range",
             "in": "query",
@@ -117,6 +132,8 @@ def test_invalid_schema_query():
         def invalid_path_parameter(cookie: NonPrimitiveSchema = Query()):
             pass
 
+        build_route_handler(invalid_path_parameter)
+
     assert (
         str(ex.value)
         == "field: 'filter' with annotation:'<class 'tests.test_routing.sample.Filter'>' in "
