@@ -1,50 +1,50 @@
 import pytest
-
-from ellar.common import Cookie, Header
-from ellar.core import TestClientFactory
+from ellar.common import Cookie, Header, Inject, ModuleRouter
 from ellar.core.connection import Request
-from ellar.core.routing import ModuleRouter
+from ellar.testing import Test
 
 mr = ModuleRouter("")
 
 
 @mr.get("/headers1")
-def headers1(request: Request, user_agent: str = Header(...)):
+def headers1(request: Inject[Request], user_agent: Header[str]):
     return user_agent
 
 
 @mr.get("/headers2")
-def headers2(request: Request, ua: str = Header(..., alias="User-Agent")):
+def headers2(request: Inject[Request], ua: Header[str, Header.P(alias="User-Agent")]):
     return ua
 
 
 @mr.get("/headers3")
-def headers3(request: Request, content_length: int = Header(...)):
+def headers3(request: Inject[Request], content_length: int = Header(...)):
     return content_length
 
 
 @mr.get("/headers4")
-def headers4(request: Request, c_len: int = Header(..., alias="Content-length")):
+def headers4(
+    request: Inject[Request], c_len: int = Header(..., alias="Content-length")
+):
     return c_len
 
 
 @mr.get("/headers5")
-def headers5(request: Request, missing: int = Header(...)):
+def headers5(request: Inject[Request], missing: int = Header(...)):
     return missing
 
 
 @mr.get("/cookies1")
-def cookies1(request: Request, weapon: str = Cookie(...)):
+def cookies1(request: Inject[Request], weapon: str = Cookie(...)):
     return weapon
 
 
 @mr.get("/cookies2")
-def cookies2(request: Request, wpn: str = Cookie(..., alias="weapon")):
+def cookies2(request: Inject[Request], wpn: str = Cookie(..., alias="weapon")):
     return wpn
 
 
-tm = TestClientFactory.create_test_module(routers=(mr,))
-client = tm.get_client()
+tm = Test.create_test_module(routers=(mr,))
+client = tm.get_test_client()
 
 
 @pytest.mark.parametrize(
