@@ -8,12 +8,12 @@ import time
 
 import anyio
 import pytest
+from ellar.app import AppFactory
+from ellar.core.staticfiles import StaticFiles
+from ellar.testing import TestClient
 from starlette.exceptions import HTTPException
 from starlette.routing import Mount
 
-from ellar.core import AppFactory, TestClient
-from ellar.core.staticfiles import StaticFiles
-
 
 def test_staticfiles(tmpdir):
     path = os.path.join(tmpdir, "example.txt")
